@@ -54,7 +54,7 @@ class StickProtocol():
         user.save()
         self.Device.objects.create(user=user, deviceId=data['deviceId'], name=data['deviceName'])
         Party.objects.create(user=user)
-        Party.objects.create(user=user, self=True)
+        Party.objects.create(user=user)
 
     def process_pre_keys(self, data, user):
         """
@@ -169,7 +169,7 @@ class StickProtocol():
             group = self.Group.objects.get(id=stickId[:36])
             if group in user.invited_groups.all():
                 authorized = True
-        elif stickId.startswith(user.party.id):  # A user is authorized to fetch SenderKeys of their own profile (user.party.id)
+        elif stickId.startswith(user.parties.filter(self=False).id) or stickId.startswith(user.parties.filter(self=True).id):  # A user is authorized to fetch SenderKeys of their own profile (user.party.id)
             authorized = True
         else:
             groupId = stickId[:36]
